#!/bin/sh
#
# The startup and shutdown script for DBMaker database
#
# Linux chkconfig script:
# chkconfig: 2345 90 10
# description: Starts and stops the DBMaker dmserver daemons at boot time \
#              and shutdown.  DBMaker provides you with a professional \
#              database system with multimedia capabilities, a native ODBC \
#              interface, large database features, and cross-platform support.
# processname: dmserver
# config: /etc/dminit.conf
#

app_name=dbmaker
app_home=`awk -F: '$1~/^'${app_name}'$/ {print $6}' /etc/passwd`
app_conf=/etc/dminit.conf

deb_start() {
  printf "Starting ${app_name}: "
  awk -F: '$1!~/^#/ {print $1,$2,$3 }' ${app_conf} |
  while read app_db arg2 app_owner; do
    [ -n "${app_db}" -a -n "${arg2}" -a -n "${app_owner}" ] || continue
    app_cmd="${app_home}/${arg2}/bin/dmserver"
    [ "`echo ${arg2} | cut -c1`" = "/" ] && app_cmd="${arg2}"
    start-stop-daemon --start -c ${app_owner} -x ${app_cmd} ${app_db} 2>&1 > /dev/null && \
      printf "${app_db} " || printf "${app_db}:FAILED "
  done
  echo
}

deb_stop() {
  printf "Stopping ${app_name}: "
  awk -F: '$1!~/^#/ {print $1,$2,$3 }' ${app_conf} |
  while read app_db arg2 app_owner; do
    [ -n "${app_db}" -a -n "${arg2}" -a -n "${app_owner}" ] || continue
    app_cmd="${app_home}/${arg2}/bin/dmserver"
    [ "`echo ${arg2} | cut -c1`" = "/" ] && app_cmd="${arg2}"
    ${app_cmd} -k ${app_db} 2>&1 >/dev/null && \
      printf "${app_db} " || printf "${app_db}:FAILED "
  done
  echo
}

# Source function library

# Check that $app_conf exists.
[ -f ${app_conf} ] || exit 0

case "$1" in
  start)
    deb_start
    ;;
  stop)
    deb_stop
    ;;
  restart)
    deb_stop
    sleep 5
    deb_start
    ;;
  *)
    echo "Usage: `basename $0` { start | stop | restart }"
    exit 64
    ;;
esac

exit 0

